
/**
 * Trieda slúži na reprezentáciu avatara hráča v hre.
 */
public class Avatar
{
	// Zoznam predmetov, ktoré vlastní avatar (predvolene je prázdny).
	private final GRobot.Zoznam<Predmet> inventár =
		new GRobot.Zoznam<Predmet>();

	// Aktuálna miestnosť, v ktorej sa avatar nachádza.
	private Miestnosť kdeSom;

	/**
	 * Konštruktor vyžaduje zadanie začiatočnej pozície avatara, to jest
	 * miestnosti, v ktorej sa hra začína.
	 */
	public Avatar(Miestnosť začiatok)
	{
		kdeSom = začiatok;
	}


	/**
	 * Vloženie predmetu do inventára.
	 */
	public void vložPredmet(Predmet predmet)
	{
		inventár.pridaj(predmet);
	}

	/**
	 * Odstránenie predmetu z inventára.
	 */
	public void odstráňPredmet(Predmet predmet)
	{
		inventár.odober(predmet);
	}

	/**
	 * Nájdenie predmetu v inventári podľa názvu.
	 */
	public Predmet hľadajPredmet(String názovPredmetu)
	{
		// Hľadám predmet (pri hľadaní používam metódu porovnajNázov).
		// Keď ho nájdem, vrátim nájdenú inštanciu.
		for (Predmet predmet : inventár)
			if (predmet.porovnajNázov(názovPredmetu))
				return predmet;

		// Inak vrátim null.
		return null;
	}

	/**
	 * Zostavenie a výpis zoznamu predmetov (inventára), ktoré avatar
	 * vlastní, na obrazovku.
	 */
	public void vypíšInventár()
	{
		if (inventár.veľkosť() <= 0) return;

		StringBuffer zoznam = new StringBuffer(
			"Vlastníš tieto predmety: " + inventár.daj(0).názov());

		for (int i = 1; i < inventár.veľkosť(); ++i)
			zoznam.append(", " + inventár.daj(i).názov());

		zoznam.append(".");
		Adventúra.vypíšText(zoznam);
	}


	/**
	 * Metóda slúži na zmenu polohy avatara, čiže na prechod do inej
	 * miestnosti.
	 */
	public void presuňDo(Miestnosť miestnosť)
	{
		kdeSom = miestnosť;
	}

	/**
	 * Metóda vráti aktuálnu polohu avatara, čiže inštanciu miestnosti,
	 * v ktorej sa nachádza.
	 */
	public Miestnosť kdeSom()
	{
		return kdeSom;
	}
}
